<?php

namespace Ebuy\Order\Forms;

use Litepie\Form\FormInterpreter;

class Order extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('order/order/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('order/order/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('order/order'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('order/order'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('order/order'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('order/order'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('order::order.label.name'),
                "placeholder" => trans('order::order.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$orderBy = [
            'created_at' => trans('order::order.label.created_at'),
            'name' => trans('order::order.label.name'),
            'status' => trans('order::order.label.status'),
        ];
        self::$groups = [
            'main' => trans('order::order.groups.main'),
            'details' => trans('order::order.groups.details'),
            'images' => trans('order::order.groups.images'),
            'settings' => trans('order::order.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('order::order.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('order::order.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('order::order.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('order::order.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'address_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('order::order.label.address_id'),
                "placeholder" => trans('order::order.placeholder.address_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'total' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('order::order.label.total'),
                "placeholder" => trans('order::order.placeholder.total'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'payment_mode' => [
                "element" => 'radios',
                "type" => 'radios',
                "label" => trans('order::order.label.payment_mode'),
                "placeholder" => trans('order::order.placeholder.payment_mode'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'payment_status' => [
                "element" => 'radios',
                "type" => 'radios',
                "label" => trans('order::order.label.payment_status'),
                "placeholder" => trans('order::order.placeholder.payment_status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'payment_id' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('order::order.label.payment_id'),
                "placeholder" => trans('order::order.placeholder.payment_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'razorpay_payment_id' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('order::order.label.razorpay_payment_id'),
                "placeholder" => trans('order::order.placeholder.razorpay_payment_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'razorpay_order_id' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('order::order.label.razorpay_order_id'),
                "placeholder" => trans('order::order.placeholder.razorpay_order_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'razorpay_signature' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('order::order.label.razorpay_signature'),
                "placeholder" => trans('order::order.placeholder.razorpay_signature'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'reason' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('order::order.label.reason'),
                "placeholder" => trans('order::order.placeholder.reason'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'comments' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('order::order.label.comments'),
                "placeholder" => trans('order::order.placeholder.comments'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
